Sequence frequency visualization among samples, displayed as
rings of nodes inside each other.
Usage
sunflower(dataset, ...)
Arguments
dataset
Input object: a matrix or a data frame.
First column is located as the outer ring, the second is right after and so
on to the last column as the inmost ring. Cell's numeric value determines
node size.